@@ -26,7 +26,7 @@ use Lintian::Tags qw(tag);
 use Lintian::Util qw(rstrip);
 
 our $PYTHON_DEPEND
-  = 'python:any | python-dev:any | python-all:any | python-all-dev:any';
+  = 'python:any | python-dev:any | python-all:any | python-all-dev:any | python2:any | python2-dev:any';
 our $PYTHON3_DEPEND
   = 'python3:any | python3-dev:any | python3-all:any | python3-all-dev:any';
 our $PYTHON2X_DEPEND = 'python2.7:any | python2.7-dev:any';
@@ -61,8 +61,14 @@ our @GLOBAL_CLEAN_DEPENDS = (
     [cdbs => qr'^include\s+/usr/share/R/debian/r-cran\.mk'],
     [dbs => qr'^include\s+/usr/share/dbs/'],
     ['dh-make-php' => qr'^include\s+/usr/share/cdbs/1/class/pear\.mk'],
-    [debhelper => qr'^include\s+/usr/share/cdbs/1/rules/debhelper\.mk'],
-    [debhelper => qr'^include\s+/usr/share/R/debian/r-cran\.mk'],
+    [
+        'debhelper | debhelper-compat' =>
+          qr'^include\s+/usr/share/cdbs/1/rules/debhelper\.mk'
+    ],
+    [
+        'debhelper | debhelper-compat' =>
+          qr'^include\s+/usr/share/R/debian/r-cran\.mk'
+    ],
     [dpatch => qr'^include\s+/usr/share/cdbs/1/rules/dpatch\.mk'],
     ['gnome-pkg-tools' => qr'^include\s+/usr/share/gnome-pkg-tools/'],
     [quilt => qr'^include\s+/usr/share/cdbs/1/rules/patchsys-quilt\.mk'],
@@ -89,7 +95,7 @@ my @GLOBAL_DEPENDS=(
 # depend on, this package is allowed (and required) in Build-Depends.
 my @RULE_CLEAN_DEPENDS =(
     [ant => qr'^\t\s*(\S+=\S+\s+)*ant\s'],
-    [debhelper => qr'^\t\s*dh_.+'],
+    ['debhelper | debhelper-compat' => qr'^\t\s*dh_.+'],
     ['dh-ocaml, ocaml-nox | ocaml' => qr'^\t\s*dh_ocamlinit\s'],
     [dpatch => qr'^\t\s*(\S+=\S+\s+)*dpatch\s'],
     ['po-debconf' => qr'^\t\s*debconf-updatepo\s'],
@@ -162,13 +168,13 @@ sub run {
     # other files, since to chase all includes we'd have to have all
     # of its build dependencies installed.
     local $_;
+    my $build_all = $info->relation('build-depends-all');
     my @arch_rules = (qr/^clean$/, qr/^binary-arch$/, qr/^build-arch$/);
     my @indep_rules = (qr/^build$/, qr/^build-indep$/, qr/^binary-indep$/);
     my (@current_targets, %rules_per_target,  %debhelper_group);
     my (%seen, %overridden);
     my ($maybe_skipping, @conditionals);
     my %variables;
-    my $uses_makefile_pl = 0;
     my $includes = 0;
 
     while (<$rules_fd>) {
@@ -196,7 +202,6 @@ sub run {
                   $makefile;
             }
         }
-        $uses_makefile_pl = 1 if m/Makefile\.PL/o;
 
         # Check for DH_COMPAT settings outside of any rule, which are now
         # deprecated.  It's a bit easier structurally to do this here than in
@@ -208,7 +213,7 @@ sub run {
         # Check for problems that can occur anywhere in debian/rules.
         if (   m/^\t\s*-(?:\$[\(\{]MAKE[\}\)]|make)\s.*(?:dist)?clean/s
             || m/^\t\s*(?:\$[\(\{]MAKE[\}\)]|make)\s(?:.*\s)?-(\w*)i.*(?:dist)?clean/s
-          ) {
+        ) {
             # Ignore "-C<dir>" (#671537)
             if (not $1 or $1 !~ m,^C,) {
                 tag 'debian-rules-ignores-make-clean-error', "line $.";
@@ -225,7 +230,7 @@ sub run {
                 (DEB_(?:HOST|BUILD|TARGET)_(?:ARCH|MULTIARCH|GNU)[A-Z_]*)\s*:?=
             /x
             && keys(%seen) == 0
-          ) {
+        ) {
             tag 'debian-rules-sets-dpkg-architecture-variable', "$1 (line $.)";
         }
 
@@ -241,10 +246,6 @@ sub run {
             }
         }
 
-        if ($uses_makefile_pl && m/install.*PREFIX/s && !/DESTDIR/) {
-            tag 'debian-rules-makemaker-prefix-is-deprecated', "line $.";
-        }
-
         # General assignment - save the variable
         if (/^\s*(?:\S+\s+)*?(\S+)\s*[:\?\+]?=\s*(.*+)?$/so) {
             # This is far too simple from a theoretical PoV, but should do
@@ -252,7 +253,9 @@ sub run {
             my ($var, $value) = ($1, $2);
             $variables{$var} = $value;
             tag 'unnecessary-source-date-epoch-assignment', "(line $.)"
-              if $var eq 'SOURCE_DATE_EPOCH';
+              if $var eq 'SOURCE_DATE_EPOCH'
+              and not $build_all->implies(
+                'dpkg-dev (>= 1.18.8) | debhelper (>= 10.10)');
         }
 
         # Keep track of whether this portion of debian/rules may be optional
@@ -406,10 +409,6 @@ sub run {
                     tag 'debian-rules-missing-required-target', $target;
                 } elsif ($typerule eq 'recommended_allindep') {
                     tag 'debian-rules-missing-recommended-target', $target;
-                } elsif ($typerule eq 'goodpractice_dfsg') {
-                    tag 'debian-rules-missing-good-practice-target-dfsg',
-                      $target
-                      if $info->repacked;
                 } else {
                     $typerule ||= '<N/A>';
                     croak(
@@ -457,6 +456,9 @@ sub run {
           if @lines and none { m/(DEB_BUILD_OPTIONS|nocheck)/ } @conditionals;
     }
 
+    tag 'debian-rules-contains-unnecessary-get-orig-source-target'
+      if any { m/^\s+uscan\b/ } @{$rules_per_target{'get-orig-source'}};
+
     # Make sure that all the required build dependencies are there.  Don't
     # issue missing-build-dependency errors for debhelper, since there's
     # another test that does that and it would just be a duplicate.
