@@ -28,6 +28,7 @@ use Lintian::Relation;
 use Lintian::Tags qw(tag);
 use Lintian::Util qw(
   file_is_encoded_in_non_utf8
+  DCTRL_COMMENTS_AT_EOL
   read_dpkg_control
   strip
 );
@@ -51,6 +52,7 @@ sub run {
     my ($pkg, $type, $info) = @_;
     my $testsuites = $info->field('testsuite', '');
     my $control = $info->index('debian/tests/control');
+    my $control_autodep8 = $info->index('debian/tests/control.autodep8');
     my $needs_control = 0;
 
     tag 'testsuite-autopkgtest-missing' if ($testsuites !~ /autopkgtest/);
@@ -80,8 +82,16 @@ sub run {
         }
 
         tag 'unnecessary-testsuite-autopkgtest-field'
-          if $info->source_field('testsuite') // '' eq 'autopkgtest';
+          if ($info->source_field('testsuite') // '') eq 'autopkgtest';
+
+        tag 'debian-tests-control-and-control-autodep8', $control,
+          $control_autodep8
+          if defined($control_autodep8);
     }
+
+    tag 'debian-tests-control-autodep8-is-obsolete', $control_autodep8
+      if defined($control_autodep8);
+
     return;
 }
 
@@ -89,7 +99,12 @@ sub check_control_contents {
     my ($info, $path) = @_;
 
     my (@paragraphs, @lines);
-    if (not eval { @paragraphs = read_dpkg_control($path, 0, \@lines); }) {
+    if (
+        not eval {
+            @paragraphs
+              = read_dpkg_control($path, DCTRL_COMMENTS_AT_EOL, \@lines);
+        }
+    ) {
         chomp $@;
         $@ =~ s/^syntax error at //;
         tag 'syntax-error-in-debian-tests-control', $@;
@@ -167,7 +182,7 @@ sub check_control_paragraph {
         }
     }
     if (exists($paragraph->{'depends'})) {
-        my $dep = Lintian::Relation->new($paragraph->{'depends'});
+        my $dep = Lintian::Relation->new(strip($paragraph->{'depends'}));
         for my $unparsable ($dep->unparsable_predicates) {
             # @ is not a valid predicate in general, but autopkgtests
             # allows it.
